Documentation
¶
Overview ¶
This file allows you to download source code of a website through Symfony Profiler (if enabled, rare case but happens). It also requires open dir
Index ¶
- Constants
- func DownloadSymfonyProfilerSRC(openDirUrl string, profilerUrl string) (*io.Directory, error)
- func GetEmailsFromHTML(html string) []string
- func GrabReactLinksFromHTML(html string) []string
- func HTMLDecode(s string) string
- func ListOpenDirFilesRecursive(openDirBaseUrl string, relativePath string) ([]string, error)
- func RecognizeContentFromHTML(html string) []string
- func RecognizePBFromHeaders(headers map[string]string) []string
- func UnpackReactMaps(jsonFiles [][]byte, inSrc bool) (*io.Directory, error)
- type CRWebsite
- type CorsAnywhere
- type CorsAnywherePort
- type ReactMap
Constants ¶
const ( PB_IIS = "iis" PB_APACHE = "apache" PB_NGINX = "nginx" PB_PHP = "php" PB_PHP_OLD = "php_old" // PHP 5.x and older, a category on its own because of the large number of vulnerabilities PB_CLOUDFLARE = "cloudflare" PB_CLOUDFRONT = "cloudfront" PB_UNKNOWN = "unknown" )
PB - Powered By
const ( ST_WORDPRESS = "wordpress" ST_JOOMLA = "joomla" ST_DRUPAL = "drupal" ST_OPENDIR = "open" // Directory listing ST_DBA = "dba" // Database Administration System (phpMyAdmin, phpPgAdmin, etc.) ST_JENKINS = "jenkins" ST_ASPNET = "aspnet" // ASP.NET errors/web services, can possibly be IIS shortname scanned ST_REACT = "react" // React App (create-react-app), could have map files ST_GITLAB = "gitlab" ST_FORGEJO = "forgejo" ST_JIRA = "jira" ST_SNRS = "snrs" // Synerise API ST_MSLOGIN = "msl" // Microsoft Login page ST_GMLOGIN = "gml" // Google Mail Login page ST_CFACCESS = "cfa" // Cloudflare Access login page ST_NGINX = "nginx" // Nginx default page ST_APACHE = "apache" // Apache default page ST_IIS = "iis" // IIS default page )
ST - Service Type
Variables ¶
This section is empty.
Functions ¶
func DownloadSymfonyProfilerSRC ¶
both openDirUrl and profilerUrl are absolute URLs, not relative paths. openDirUrl is the root of the website which has to be opendir, profilerUrl is the URL of the profiler Example usage: DownloadSymfonyProfilerSRC("http://localhost:8000", "http://localhost:8000/_profiler")
func GetEmailsFromHTML ¶
Try grabbing all emails from the HTML
func GrabReactLinksFromHTML ¶
Grabs internal links from a React HTML file, adding .map to the end has a chance of working returns a list of links (without .map or url, only relative path)
func HTMLDecode ¶
func RecognizePBFromHeaders ¶
Types ¶
type CorsAnywhere ¶
type CorsAnywhere struct {
// contains filtered or unexported fields
}
func NewCorsAnywhere ¶
func NewCorsAnywhere(url string) *CorsAnywhere
func (*CorsAnywhere) GetOpenPorts ¶
func (c *CorsAnywhere) GetOpenPorts() []*CorsAnywherePort
func (*CorsAnywhere) TestPort ¶
func (c *CorsAnywhere) TestPort(port uint16) *CorsAnywherePort
func (*CorsAnywhere) TestPorts ¶
func (c *CorsAnywhere) TestPorts(ports []uint16, threads uint8) []*CorsAnywherePort
type CorsAnywherePort ¶
type ReactMap ¶
type ReactMap struct {
// Version int `json:"version"`
// File string `json:"file"`
// Mappings string `json:"mappings"`
// Names []string `json:"names"`
// SourceRoot string `json:"sourceRoot"`
// commented out until i find a use for these
Sources []string `json:"sources"`
SourcesContent []string `json:"sourcesContent"`
}
Click to show internal directories.
Click to hide internal directories.